Further reading
===============

* The best explanation of what should be put in each metadata field I've found is the `Guide to Photo Metadata Fields <http://www.photometadata.org/META-Resources-Field-Guide-to-Metadata>`_.
* `Google Maps JavaScript API v3 tutorial <https://developers.google.com/maps/documentation/javascript/tutorial>`_.
* `Bing Maps AJAX Control, Version 7.0 <http://msdn.microsoft.com/en-us/library/gg427610.aspx>`_.
* `Leaflet, An Open-Source JavaScript Library for Mobile-Friendly Interactive Maps by CloudMade <http://leafletjs.com/index.html>`_.